#[non_exhaustive]pub enum CreateAdvancedPromptOptimizationJobError {
AccessDeniedException(AccessDeniedException),
ConflictException(ConflictException),
InternalServerException(InternalServerException),
ResourceNotFoundException(ResourceNotFoundException),
ServiceQuotaExceededException(ServiceQuotaExceededException),
ThrottlingException(ThrottlingException),
TooManyTagsException(TooManyTagsException),
ValidationException(ValidationException),
Unhandled(Unhandled),
}Expand description
Error type for the CreateAdvancedPromptOptimizationJobError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AccessDeniedException(AccessDeniedException)
The request is denied because of missing access permissions.
ConflictException(ConflictException)
Error occurred because of a conflict while performing an operation.
InternalServerException(InternalServerException)
An internal server error occurred. Retry your request.
ResourceNotFoundException(ResourceNotFoundException)
The specified resource Amazon Resource Name (ARN) was not found. Check the Amazon Resource Name (ARN) and try your request again.
ServiceQuotaExceededException(ServiceQuotaExceededException)
The number of requests exceeds the service quota. Resubmit your request later.
ThrottlingException(ThrottlingException)
The number of requests exceeds the limit. Resubmit your request later.
TooManyTagsException(TooManyTagsException)
The request contains more tags than can be associated with a resource (50 tags per resource). The maximum number of tags includes both existing tags and those included in your current request.
ValidationException(ValidationException)
Input validation failed. Check your request parameters and retry the request.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl CreateAdvancedPromptOptimizationJobError
impl CreateAdvancedPromptOptimizationJobError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the CreateAdvancedPromptOptimizationJobError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the CreateAdvancedPromptOptimizationJobError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_access_denied_exception(&self) -> bool
pub fn is_access_denied_exception(&self) -> bool
Returns true if the error kind is CreateAdvancedPromptOptimizationJobError::AccessDeniedException.
Sourcepub fn is_conflict_exception(&self) -> bool
pub fn is_conflict_exception(&self) -> bool
Returns true if the error kind is CreateAdvancedPromptOptimizationJobError::ConflictException.
Sourcepub fn is_internal_server_exception(&self) -> bool
pub fn is_internal_server_exception(&self) -> bool
Returns true if the error kind is CreateAdvancedPromptOptimizationJobError::InternalServerException.
Sourcepub fn is_resource_not_found_exception(&self) -> bool
pub fn is_resource_not_found_exception(&self) -> bool
Returns true if the error kind is CreateAdvancedPromptOptimizationJobError::ResourceNotFoundException.
Sourcepub fn is_service_quota_exceeded_exception(&self) -> bool
pub fn is_service_quota_exceeded_exception(&self) -> bool
Returns true if the error kind is CreateAdvancedPromptOptimizationJobError::ServiceQuotaExceededException.
Sourcepub fn is_throttling_exception(&self) -> bool
pub fn is_throttling_exception(&self) -> bool
Returns true if the error kind is CreateAdvancedPromptOptimizationJobError::ThrottlingException.
Returns true if the error kind is CreateAdvancedPromptOptimizationJobError::TooManyTagsException.
Sourcepub fn is_validation_exception(&self) -> bool
pub fn is_validation_exception(&self) -> bool
Returns true if the error kind is CreateAdvancedPromptOptimizationJobError::ValidationException.