#[non_exhaustive]pub struct AdvancedPromptOptimizationInputConfig {
pub s3_uri: String,
}Expand description
Contains the input data configuration for an advanced prompt optimization job.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.s3_uri: StringThe S3 URI of the JSONL input file containing prompt templates and evaluation samples.
Implementations
Sourceimpl AdvancedPromptOptimizationInputConfig
impl AdvancedPromptOptimizationInputConfig
Sourcepub fn builder() -> AdvancedPromptOptimizationInputConfigBuilder
pub fn builder() -> AdvancedPromptOptimizationInputConfigBuilder
Creates a new builder-style object to manufacture AdvancedPromptOptimizationInputConfig.