#[non_exhaustive]pub struct AdvancedPromptOptimizationJobSummary {
pub job_arn: String,
pub job_name: String,
pub job_status: AdvancedPromptOptimizationJobStatus,
pub creation_time: DateTime,
pub last_modified_time: Option<DateTime>,
}Expand description
Contains a summary of an advanced prompt optimization job.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.job_arn: StringThe Amazon Resource Name (ARN) of the job.
job_name: StringThe name of the job.
job_status: AdvancedPromptOptimizationJobStatusThe status of the job.
creation_time: DateTimeThe time at which the job was created.
last_modified_time: Option<DateTime>The time at which the job was last modified.
Implementations
Sourceimpl AdvancedPromptOptimizationJobSummary
impl AdvancedPromptOptimizationJobSummary
Sourcepub fn job_status(&self) -> &AdvancedPromptOptimizationJobStatus
pub fn job_status(&self) -> &AdvancedPromptOptimizationJobStatus
The status of the job.
Sourcepub fn creation_time(&self) -> &DateTime
pub fn creation_time(&self) -> &DateTime
The time at which the job was created.
Sourcepub fn last_modified_time(&self) -> Option<&DateTime>
pub fn last_modified_time(&self) -> Option<&DateTime>
The time at which the job was last modified.
Sourceimpl AdvancedPromptOptimizationJobSummary
impl AdvancedPromptOptimizationJobSummary
Sourcepub fn builder() -> AdvancedPromptOptimizationJobSummaryBuilder
pub fn builder() -> AdvancedPromptOptimizationJobSummaryBuilder
Creates a new builder-style object to manufacture AdvancedPromptOptimizationJobSummary.