#[non_exhaustive]pub struct AutomatedReasoningPolicyIterativeRefinementContent {
pub documents: Vec<AutomatedReasoningPolicyBuildWorkflowDocument>,
pub feedback: Option<String>,
}Expand description
Configuration for an iterative policy refinement workflow, including source documents to process and optional feedback to guide the refinement.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.documents: Vec<AutomatedReasoningPolicyBuildWorkflowDocument>Source documents used for iterative policy refinement. These documents provide context for refining the policy definition.
feedback: Option<String>Optional feedback to guide the iterative refinement workflow. Provide specific instructions or constraints for policy refinement.
Implementations
Sourceimpl AutomatedReasoningPolicyIterativeRefinementContent
impl AutomatedReasoningPolicyIterativeRefinementContent
Sourcepub fn documents(&self) -> &[AutomatedReasoningPolicyBuildWorkflowDocument]
pub fn documents(&self) -> &[AutomatedReasoningPolicyBuildWorkflowDocument]
Source documents used for iterative policy refinement. These documents provide context for refining the policy definition.
Sourceimpl AutomatedReasoningPolicyIterativeRefinementContent
impl AutomatedReasoningPolicyIterativeRefinementContent
Sourcepub fn builder() -> AutomatedReasoningPolicyIterativeRefinementContentBuilder
pub fn builder() -> AutomatedReasoningPolicyIterativeRefinementContentBuilder
Creates a new builder-style object to manufacture AutomatedReasoningPolicyIterativeRefinementContent.