#[non_exhaustive]pub struct ModelConfiguration {
pub model_id: String,
pub inference_config: Option<InferenceConfiguration>,
pub additional_model_request_fields: Option<HashMap<String, Document>>,
}Expand description
Contains the configuration for a model used in an advanced prompt optimization job, including the model ID and inference parameters.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.model_id: StringThe ID of the model to use for optimization.
inference_config: Option<InferenceConfiguration>The inference configuration for the model, including parameters such as maximum tokens, temperature, and top-p.
additional_model_request_fields: Option<HashMap<String, Document>>Additional model request fields. Use this to pass model-specific parameters that are not included in the standard inference configuration.
Implementations
Sourceimpl ModelConfiguration
impl ModelConfiguration
Sourcepub fn inference_config(&self) -> Option<&InferenceConfiguration>
pub fn inference_config(&self) -> Option<&InferenceConfiguration>
The inference configuration for the model, including parameters such as maximum tokens, temperature, and top-p.
Sourceimpl ModelConfiguration
impl ModelConfiguration
Sourcepub fn builder() -> ModelConfigurationBuilder
pub fn builder() -> ModelConfigurationBuilder
Creates a new builder-style object to manufacture ModelConfiguration.